# Deployment Instructions for PHP Photo Gallery

## Requirements
- Apache web server
- PHP 7.4 or higher with the following extensions:
  - GD (for image processing)
  - PDO MySQL (for database connectivity)
  - JSON
  - cURL
  - mbstring
  - XML
- MySQL 5.7 or higher

## Deployment Steps

### 1. Database Setup
1. Create a MySQL database for your photo gallery
   ```sql
   CREATE DATABASE photo_gallery;
   CREATE USER 'gallery_user'@'localhost' IDENTIFIED BY 'your_secure_password';
   GRANT ALL PRIVILEGES ON photo_gallery.* TO 'gallery_user'@'localhost';
   FLUSH PRIVILEGES;
   ```

2. Import the database schema
   ```
   mysql -u gallery_user -p photo_gallery < database_schema.sql
   ```

### 2. Google OAuth Setup
1. Go to the [Google Developer Console](https://console.developers.google.com/)
2. Create a new project
3. Navigate to "Credentials" and create OAuth 2.0 Client ID
4. Set the authorized redirect URI to `http://your-domain.com/photo_gallery/auth/google_callback.php`
5. Note your Client ID and Client Secret

### 3. Application Setup
1. Copy all files to your web server's document root or a subdirectory
   ```
   cp -r photo_gallery/ /var/www/html/
   ```

2. Create and set permissions for upload directories
   ```
   mkdir -p /var/www/html/photo_gallery/uploads/thumbnails
   chmod 755 /var/www/html/photo_gallery/uploads
   chmod 755 /var/www/html/photo_gallery/uploads/thumbnails
   chown -R www-data:www-data /var/www/html/photo_gallery/uploads
   ```

3. Update the configuration file with your settings
   ```
   nano /var/www/html/photo_gallery/config.php
   ```
   
   Update the following:
   - Database credentials
   - Google OAuth credentials
   - Base URL to match your domain
   - Session security settings

### 4. Apache Configuration
1. Ensure mod_rewrite is enabled
   ```
   a2enmod rewrite
   ```

2. Configure your virtual host (if needed)
   ```
   nano /etc/apache2/sites-available/photo-gallery.conf
   ```
   
   Example configuration:
   ```
   <VirtualHost *:80>
       ServerName your-domain.com
       DocumentRoot /var/www/html/photo_gallery
       
       <Directory /var/www/html/photo_gallery>
           Options -Indexes +FollowSymLinks
           AllowOverride All
           Require all granted
       </Directory>
       
       ErrorLog ${APACHE_LOG_DIR}/photo_gallery_error.log
       CustomLog ${APACHE_LOG_DIR}/photo_gallery_access.log combined
   </VirtualHost>
   ```

3. Enable the site and restart Apache
   ```
   a2ensite photo-gallery.conf
   systemctl restart apache2
   ```

### 5. Security Considerations
1. Update the `HASH_SALT` in config.php to a random string
2. Ensure all directories have proper permissions
3. Consider using HTTPS for secure connections
4. Regularly backup your database
5. Keep PHP and all extensions updated

### 6. Testing
1. Visit your site at `http://your-domain.com/photo_gallery/`
2. Test the login functionality
3. Upload some test images
4. Create albums and test all features

## Troubleshooting
- Check Apache error logs: `tail -f /var/log/apache2/error.log`
- Check PHP error logs: `tail -f /var/log/php/error.log`
- Ensure file permissions are correct
- Verify database connection settings
- Confirm Google OAuth credentials are correct

## Maintenance
- Regularly backup your database and uploaded images
- Monitor disk space usage, especially in the uploads directory
- Update PHP and Apache when security patches are available
