<?php
/**
 * Google authentication callback handler
 */
require_once '../config.php';
require_once '../includes/session.php';
require_once '../includes/user.php';
require_once '../vendor/autoload.php';

// Initialize session
$session = Session::getInstance();

// Create Google client
$client = new Google_Client();
$client->setClientId(GOOGLE_CLIENT_ID);
$client->setClientSecret(GOOGLE_CLIENT_SECRET);
$client->setRedirectUri(GOOGLE_REDIRECT_URI);

// Handle the callback
if (isset($_GET['code'])) {
    try {
        // Exchange authorization code for access token
        $token = $client->fetchAccessTokenWithAuthCode($_GET['code']);
        $client->setAccessToken($token);
        
        // Get user profile information
        $google_oauth = new Google_Service_Oauth2($client);
        $google_account_info = $google_oauth->userinfo->get();
        
        // Extract user data
        $google_data = [
            'google_id' => $google_account_info->getId(),
            'email' => $google_account_info->getEmail(),
            'display_name' => $google_account_info->getName(),
            'profile_picture' => $google_account_info->getPicture()
        ];
        
        // Initialize user object
        $user = new User();
        
        // Check if user exists
        if ($user->getUserByGoogleId($google_data['google_id'])) {
            // User exists, update last login
            $user->updateLastLogin();
        } else {
            // Create new user
            if (!$user->createUserFromGoogle($google_data)) {
                // Error creating user
                $_SESSION['error'] = "Failed to create user account.";
                header('Location: ' . BASE_URL . 'login.php');
                exit;
            }
        }
        
        // Create user session
        if ($session->createUserSession($user->getUserId())) {
            // Redirect to home page
            header('Location: ' . BASE_URL);
            exit;
        } else {
            // Error creating session
            $_SESSION['error'] = "Failed to create user session.";
            header('Location: ' . BASE_URL . 'login.php');
            exit;
        }
        
    } catch (Exception $e) {
        // Handle authentication error
        $_SESSION['error'] = "Authentication failed: " . $e->getMessage();
        header('Location: ' . BASE_URL . 'login.php');
        exit;
    }
} else {
    // No authorization code, redirect to login page
    $_SESSION['error'] = "Authentication failed: No authorization code received.";
    header('Location: ' . BASE_URL . 'login.php');
    exit;
}
