<?php
/**
 * Edit Album page for the photo gallery
 */
require_once 'config.php';
require_once 'includes/auth_utils.php';
require_once 'includes/album.php';

// Require login
$user = require_login();

// Check if album ID is provided
if (!isset($_GET['id']) || empty($_GET['id'])) {
    $_SESSION['error'] = 'Album ID is required.';
    header('Location: my_albums.php');
    exit;
}

$album_id = (int)$_GET['id'];

// Get album data
$album = new Album();
$album_data = $album->getAlbumById($album_id);

// Check if album exists and belongs to the user
if (!$album_data || $album_data['user_id'] != $user->getUserId()) {
    $_SESSION['error'] = 'Album not found or you do not have permission to edit it.';
    header('Location: my_albums.php');
    exit;
}

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $album_name = isset($_POST['album_name']) ? trim($_POST['album_name']) : '';
    $description = isset($_POST['description']) ? trim($_POST['description']) : '';
    $is_public = isset($_POST['is_public']) ? true : false;
    
    // Validate album name
    if (empty($album_name)) {
        $_SESSION['error'] = 'Album name is required.';
    } else {
        // Update album
        if ($album->updateAlbum($album_id, $album_name, $description, $is_public)) {
            $_SESSION['success'] = 'Album updated successfully.';
            header('Location: view_album.php?id=' . $album_id);
            exit;
        } else {
            $_SESSION['error'] = 'Failed to update album.';
        }
    }
}

// Set page title
$page_title = 'Edit Album';

// Include header
include 'includes/header.php';
?>

<div class="row">
    <div class="col-md-12">
        <nav aria-label="breadcrumb">
            <ol class="breadcrumb">
                <li class="breadcrumb-item"><a href="index.php">Home</a></li>
                <li class="breadcrumb-item"><a href="my_albums.php">My Albums</a></li>
                <li class="breadcrumb-item"><a href="view_album.php?id=<?php echo $album_id; ?>"><?php echo htmlspecialchars($album_data['album_name']); ?></a></li>
                <li class="breadcrumb-item active" aria-current="page">Edit</li>
            </ol>
        </nav>
    </div>
</div>

<div class="row">
    <div class="col-md-8">
        <div class="card">
            <div class="card-header">
                <h5 class="card-title mb-0">Edit Album</h5>
            </div>
            <div class="card-body">
                <form action="edit_album.php?id=<?php echo $album_id; ?>" method="post">
                    <div class="mb-3">
                        <label for="album_name" class="form-label">Album Name</label>
                        <input type="text" class="form-control" id="album_name" name="album_name" value="<?php echo htmlspecialchars($album_data['album_name']); ?>" required>
                    </div>
                    
                    <div class="mb-3">
                        <label for="description" class="form-label">Description</label>
                        <textarea class="form-control" id="description" name="description" rows="4"><?php echo htmlspecialchars($album_data['description']); ?></textarea>
                    </div>
                    
                    <div class="mb-3 form-check">
                        <input type="checkbox" class="form-check-input" id="is_public" name="is_public" <?php echo $album_data['is_public'] ? 'checked' : ''; ?>>
                        <label class="form-check-label" for="is_public">Make album public</label>
                        <div class="form-text">Public albums will be visible to everyone.</div>
                    </div>
                    
                    <button type="submit" class="btn btn-primary">Save Changes</button>
                    <a href="view_album.php?id=<?php echo $album_id; ?>" class="btn btn-secondary">Cancel</a>
                </form>
            </div>
        </div>
    </div>
    
    <div class="col-md-4">
        <div class="card">
            <div class="card-header">
                <h5 class="card-title mb-0">Album Information</h5>
            </div>
            <div class="card-body">
                <p><strong>Created:</strong> <?php echo date('F d, Y', strtotime($album_data['created_at'])); ?></p>
                <p><strong>Last Updated:</strong> <?php echo date('F d, Y', strtotime($album_data['updated_at'])); ?></p>
                <p><strong>Images:</strong> <?php echo $album_data['image_count']; ?></p>
                <p><strong>Status:</strong> <?php echo $album_data['is_public'] ? 'Public' : 'Private'; ?></p>
            </div>
        </div>
    </div>
</div>

<?php
// Include footer
include 'includes/footer.php';
?>
