<?php
/**
 * Edit Image page for the photo gallery
 */
require_once 'config.php';
require_once 'includes/auth_utils.php';
require_once 'includes/image.php';

// Require login
$user = require_login();

// Check if image ID is provided
if (!isset($_GET['id']) || empty($_GET['id'])) {
    $_SESSION['error'] = 'Image ID is required.';
    header('Location: my_images.php');
    exit;
}

$image_id = (int)$_GET['id'];

// Get image data
$image = new Image();
$img_data = $image->getImageById($image_id);

// Check if image exists and belongs to the user
if (!$img_data || $img_data['user_id'] != $user->getUserId()) {
    $_SESSION['error'] = 'Image not found or you do not have permission to edit it.';
    header('Location: my_images.php');
    exit;
}

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $title = isset($_POST['title']) ? $_POST['title'] : '';
    $description = isset($_POST['description']) ? $_POST['description'] : '';
    $is_public = isset($_POST['is_public']) ? true : false;
    
    // Update image
    if ($image->updateImage($image_id, $title, $description, $is_public)) {
        $_SESSION['success'] = 'Image updated successfully.';
        header('Location: view_image.php?id=' . $image_id);
        exit;
    } else {
        $_SESSION['error'] = 'Failed to update image.';
    }
}

// Set page title
$page_title = 'Edit Image';

// Include header
include 'includes/header.php';
?>

<div class="row">
    <div class="col-md-12">
        <nav aria-label="breadcrumb">
            <ol class="breadcrumb">
                <li class="breadcrumb-item"><a href="index.php">Home</a></li>
                <li class="breadcrumb-item"><a href="my_images.php">My Images</a></li>
                <li class="breadcrumb-item"><a href="view_image.php?id=<?php echo $image_id; ?>"><?php echo htmlspecialchars($img_data['title'] ?: 'Untitled'); ?></a></li>
                <li class="breadcrumb-item active" aria-current="page">Edit</li>
            </ol>
        </nav>
    </div>
</div>

<div class="row">
    <div class="col-md-8">
        <div class="card">
            <div class="card-header">
                <h5 class="card-title mb-0">Edit Image</h5>
            </div>
            <div class="card-body">
                <form action="edit_image.php?id=<?php echo $image_id; ?>" method="post">
                    <div class="mb-3">
                        <label for="title" class="form-label">Title</label>
                        <input type="text" class="form-control" id="title" name="title" value="<?php echo htmlspecialchars($img_data['title']); ?>">
                    </div>
                    
                    <div class="mb-3">
                        <label for="description" class="form-label">Description</label>
                        <textarea class="form-control" id="description" name="description" rows="4"><?php echo htmlspecialchars($img_data['description']); ?></textarea>
                    </div>
                    
                    <div class="mb-3 form-check">
                        <input type="checkbox" class="form-check-input" id="is_public" name="is_public" <?php echo $img_data['is_public'] ? 'checked' : ''; ?>>
                        <label class="form-check-label" for="is_public">Make image public</label>
                        <div class="form-text">Public images will be visible to everyone.</div>
                    </div>
                    
                    <button type="submit" class="btn btn-primary">Save Changes</button>
                    <a href="view_image.php?id=<?php echo $image_id; ?>" class="btn btn-secondary">Cancel</a>
                </form>
            </div>
        </div>
    </div>
    
    <div class="col-md-4">
        <div class="card">
            <div class="card-header">
                <h5 class="card-title mb-0">Image Preview</h5>
            </div>
            <div class="card-body text-center">
                <img src="<?php echo htmlspecialchars($img_data['thumbnail_path']); ?>" class="img-fluid" alt="<?php echo htmlspecialchars($img_data['title'] ?: $img_data['file_name']); ?>">
            </div>
        </div>
    </div>
</div>

<?php
// Include footer
include 'includes/footer.php';
?>
