<?php
/**
 * Session management class
 */
class Session {
    private static $instance = null;
    private $user;
    
    private function __construct() {
        session_start();
        require_once 'user.php';
        $this->user = new User();
    }
    
    public static function getInstance() {
        if (self::$instance == null) {
            self::$instance = new Session();
        }
        return self::$instance;
    }
    
    /**
     * Check if user is logged in
     */
    public function isLoggedIn() {
        if (isset($_SESSION['user_session'])) {
            return $this->user->validateSession($_SESSION['user_session']);
        }
        
        // Check for cookie
        if (isset($_COOKIE['user_session'])) {
            if ($this->user->validateSession($_COOKIE['user_session'])) {
                $_SESSION['user_session'] = $_COOKIE['user_session'];
                return true;
            }
        }
        
        return false;
    }
    
    /**
     * Create a new session for the user
     */
    public function createUserSession($user_id) {
        $session_id = $this->user->createSession();
        if ($session_id) {
            $_SESSION['user_session'] = $session_id;
            
            // Set cookie for persistent login (30 days)
            setcookie('user_session', $session_id, time() + (30 * 24 * 60 * 60), '/', '', false, true);
            return true;
        }
        return false;
    }
    
    /**
     * Destroy the current session
     */
    public function destroySession() {
        if (isset($_SESSION['user_session'])) {
            $this->user->deleteSession($_SESSION['user_session']);
            unset($_SESSION['user_session']);
        }
        
        if (isset($_COOKIE['user_session'])) {
            $this->user->deleteSession($_COOKIE['user_session']);
            setcookie('user_session', '', time() - 3600, '/', '', false, true);
        }
        
        session_destroy();
        return true;
    }
    
    /**
     * Get the current user
     */
    public function getUser() {
        if ($this->isLoggedIn()) {
            return $this->user;
        }
        return null;
    }
}
