<?php
/**
 * Home page for the photo gallery
 */
require_once 'config.php';
require_once 'includes/session.php';
require_once 'includes/image.php';

// Set page title
$page_title = 'Home';

// Include header
include 'includes/header.php';

// Get recent public images
$image = new Image();
$recent_images = $image->getPublicImages(8);
?>

<div class="row">
    <div class="col-md-12">
        <div class="jumbotron bg-light p-5 rounded">
            <h1 class="display-4">Welcome to Photo Gallery</h1>
            <p class="lead">A place to store, organize, and share your photos securely.</p>
            <?php if (!$user): ?>
            <hr class="my-4">
            <p>Sign in with your Google account to start uploading and managing your photos.</p>
            <a class="btn btn-primary btn-lg" href="login.php" role="button">Sign In</a>
            <?php else: ?>
            <hr class="my-4">
            <p>Upload new photos or manage your existing albums.</p>
            <a class="btn btn-primary btn-lg" href="upload.php" role="button">Upload Photos</a>
            <a class="btn btn-secondary btn-lg" href="my_albums.php" role="button">My Albums</a>
            <?php endif; ?>
        </div>
    </div>
</div>

<?php if (!empty($recent_images)): ?>
<div class="row mt-5">
    <div class="col-md-12">
        <h2>Recent Photos</h2>
        <hr>
    </div>
</div>

<div class="row">
    <?php foreach ($recent_images as $img): ?>
    <div class="col-md-3">
        <div class="card">
            <a href="view_image.php?id=<?php echo $img['image_id']; ?>">
                <img src="<?php echo htmlspecialchars($img['thumbnail_path']); ?>" class="card-img-top" alt="<?php echo htmlspecialchars($img['title'] ?: $img['file_name']); ?>">
            </a>
            <div class="card-body">
                <h5 class="card-title"><?php echo htmlspecialchars($img['title'] ?: 'Untitled'); ?></h5>
                <p class="card-text small text-muted">By <?php echo htmlspecialchars($img['user_name']); ?></p>
                <p class="card-text small text-muted"><?php echo date('M d, Y', strtotime($img['upload_date'])); ?></p>
                <a href="view_image.php?id=<?php echo $img['image_id']; ?>" class="btn btn-sm btn-primary">View</a>
            </div>
        </div>
    </div>
    <?php endforeach; ?>
</div>

<div class="row mt-3">
    <div class="col-md-12 text-center">
        <a href="explore.php" class="btn btn-outline-primary">Explore More Photos</a>
    </div>
</div>
<?php endif; ?>

<?php
// Include footer
include 'includes/footer.php';
?>
