<?php
/**
 * My Albums page for the photo gallery
 */
require_once 'config.php';
require_once 'includes/auth_utils.php';
require_once 'includes/album.php';

// Require login
$user = require_login();

// Set page title
$page_title = 'My Albums';

// Get user's albums
$album = new Album();
$user_albums = $album->getAlbumsByUserId($user->getUserId());

// Include header
include 'includes/header.php';
?>

<div class="row">
    <div class="col-md-12">
        <div class="d-flex justify-content-between align-items-center mb-4">
            <h1>My Albums</h1>
            <button type="button" class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#createAlbumModal">
                <i class="fas fa-plus"></i> Create Album
            </button>
        </div>
        <hr>
    </div>
</div>

<?php if (empty($user_albums)): ?>
<div class="row">
    <div class="col-md-12">
        <div class="alert alert-info">
            <p>You haven't created any albums yet.</p>
            <button type="button" class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#createAlbumModal">
                Create Your First Album
            </button>
        </div>
    </div>
</div>
<?php else: ?>
<div class="row">
    <?php foreach ($user_albums as $alb): ?>
    <div class="col-md-4 mb-4">
        <div class="card album-card h-100">
            <?php if ($alb['cover_image_id']): ?>
            <a href="view_album.php?id=<?php echo $alb['album_id']; ?>">
                <img src="<?php echo htmlspecialchars($alb['cover_image_path'] ?? 'assets/img/album-placeholder.jpg'); ?>" class="card-img-top" alt="<?php echo htmlspecialchars($alb['album_name']); ?>">
            </a>
            <?php else: ?>
            <a href="view_album.php?id=<?php echo $alb['album_id']; ?>">
                <div class="card-img-top d-flex align-items-center justify-content-center bg-light">
                    <i class="fas fa-images fa-3x text-muted"></i>
                </div>
            </a>
            <?php endif; ?>
            <div class="card-body">
                <h5 class="card-title"><?php echo htmlspecialchars($alb['album_name']); ?></h5>
                <?php if (!empty($alb['description'])): ?>
                <p class="card-text small"><?php echo htmlspecialchars(substr($alb['description'], 0, 100)) . (strlen($alb['description']) > 100 ? '...' : ''); ?></p>
                <?php endif; ?>
                <p class="card-text small text-muted">
                    <i class="fas fa-image"></i> <?php echo $alb['image_count']; ?> images
                </p>
                <p class="card-text small text-muted">
                    <i class="fas fa-calendar"></i> Created: <?php echo date('M d, Y', strtotime($alb['created_at'])); ?>
                </p>
            </div>
            <div class="card-footer bg-transparent">
                <div class="d-flex justify-content-between">
                    <a href="view_album.php?id=<?php echo $alb['album_id']; ?>" class="btn btn-sm btn-primary">View</a>
                    <a href="edit_album.php?id=<?php echo $alb['album_id']; ?>" class="btn btn-sm btn-secondary">Edit</a>
                </div>
            </div>
        </div>
    </div>
    <?php endforeach; ?>
</div>
<?php endif; ?>

<!-- Create Album Modal -->
<div class="modal fade" id="createAlbumModal" tabindex="-1" aria-labelledby="createAlbumModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="createAlbumModalLabel">Create New Album</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <form action="create_album.php" method="post">
                <div class="modal-body">
                    <div class="mb-3">
                        <label for="album_name" class="form-label">Album Name</label>
                        <input type="text" class="form-control" id="album_name" name="album_name" required>
                    </div>
                    <div class="mb-3">
                        <label for="description" class="form-label">Description</label>
                        <textarea class="form-control" id="description" name="description" rows="3"></textarea>
                    </div>
                    <div class="mb-3 form-check">
                        <input type="checkbox" class="form-check-input" id="is_public" name="is_public">
                        <label class="form-check-label" for="is_public">Make album public</label>
                        <div class="form-text">Public albums will be visible to everyone.</div>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                    <button type="submit" class="btn btn-primary">Create Album</button>
                </div>
            </form>
        </div>
    </div>
</div>

<?php
// Include footer
include 'includes/footer.php';
?>
