<?php
/**
 * My Images page for the photo gallery
 */
require_once 'config.php';
require_once 'includes/auth_utils.php';
require_once 'includes/image.php';

// Require login
$user = require_login();

// Set page title
$page_title = 'My Images';

// Get user's images
$image = new Image();
$user_images = $image->getImagesByUserId($user->getUserId());

// Include header
include 'includes/header.php';
?>

<div class="row">
    <div class="col-md-12">
        <div class="d-flex justify-content-between align-items-center mb-4">
            <h1>My Images</h1>
            <a href="upload.php" class="btn btn-primary">
                <i class="fas fa-upload"></i> Upload Images
            </a>
        </div>
        <hr>
    </div>
</div>

<?php if (empty($user_images)): ?>
<div class="row">
    <div class="col-md-12">
        <div class="alert alert-info">
            <p>You haven't uploaded any images yet.</p>
            <a href="upload.php" class="btn btn-primary">Upload Your First Image</a>
        </div>
    </div>
</div>
<?php else: ?>
<div class="row">
    <?php foreach ($user_images as $img): ?>
    <div class="col-md-3 mb-4">
        <div class="card h-100">
            <a href="view_image.php?id=<?php echo $img['image_id']; ?>">
                <img src="<?php echo htmlspecialchars($img['thumbnail_path']); ?>" class="card-img-top" alt="<?php echo htmlspecialchars($img['title'] ?: $img['file_name']); ?>">
            </a>
            <div class="card-body">
                <h5 class="card-title"><?php echo htmlspecialchars($img['title'] ?: 'Untitled'); ?></h5>
                <p class="card-text small text-muted"><?php echo date('M d, Y', strtotime($img['upload_date'])); ?></p>
                <div class="d-flex justify-content-between">
                    <a href="view_image.php?id=<?php echo $img['image_id']; ?>" class="btn btn-sm btn-primary">View</a>
                    <a href="edit_image.php?id=<?php echo $img['image_id']; ?>" class="btn btn-sm btn-secondary">Edit</a>
                </div>
            </div>
            <div class="card-footer bg-transparent">
                <small class="text-muted">
                    <?php echo $img['is_public'] ? '<i class="fas fa-globe"></i> Public' : '<i class="fas fa-lock"></i> Private'; ?>
                </small>
            </div>
        </div>
    </div>
    <?php endforeach; ?>
</div>
<?php endif; ?>

<?php
// Include footer
include 'includes/footer.php';
?>
