<?php
/**
 * Upload page for the photo gallery
 */
require_once 'config.php';
require_once 'includes/auth_utils.php';
require_once 'includes/image.php';
require_once 'includes/album.php';

// Require login
$user = require_login();

// Set page title
$page_title = 'Upload Images';

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Check if files were uploaded
    if (isset($_FILES['images']) && !empty($_FILES['images']['name'][0])) {
        $image = new Image();
        $success_count = 0;
        $error_count = 0;
        
        // Get form data
        $title = isset($_POST['title']) ? $_POST['title'] : '';
        $description = isset($_POST['description']) ? $_POST['description'] : '';
        $is_public = isset($_POST['is_public']) ? true : false;
        $album_id = isset($_POST['album_id']) && !empty($_POST['album_id']) ? (int)$_POST['album_id'] : null;
        
        // Process each uploaded file
        $file_count = count($_FILES['images']['name']);
        for ($i = 0; $i < $file_count; $i++) {
            if ($_FILES['images']['error'][$i] === UPLOAD_ERR_OK) {
                // Create file array for single image
                $file = [
                    'name' => $_FILES['images']['name'][$i],
                    'type' => $_FILES['images']['type'][$i],
                    'tmp_name' => $_FILES['images']['tmp_name'][$i],
                    'error' => $_FILES['images']['error'][$i],
                    'size' => $_FILES['images']['size'][$i]
                ];
                
                // Generate individual title if multiple files
                $image_title = $file_count > 1 ? $title . ' (' . ($i + 1) . ')' : $title;
                
                // Upload image
                $image_id = $image->uploadImage($user->getUserId(), $file, $image_title, $description, $is_public);
                
                if ($image_id) {
                    $success_count++;
                    
                    // Add to album if selected
                    if ($album_id) {
                        $album = new Album();
                        $album->addImageToAlbum($album_id, $image_id);
                    }
                } else {
                    $error_count++;
                }
            } else {
                $error_count++;
            }
        }
        
        // Set messages
        if ($success_count > 0) {
            $_SESSION['success'] = $success_count . ' image(s) uploaded successfully.';
        }
        
        if ($error_count > 0) {
            $_SESSION['error'] = $error_count . ' image(s) failed to upload.';
        }
        
        // Redirect to my images page
        header('Location: my_images.php');
        exit;
    } else {
        $_SESSION['error'] = 'Please select at least one image to upload.';
    }
}

// Get user's albums for dropdown
$album = new Album();
$user_albums = $album->getAlbumsByUserId($user->getUserId());

// Include header
include 'includes/header.php';
?>

<div class="row">
    <div class="col-md-12">
        <h1>Upload Images</h1>
        <hr>
    </div>
</div>

<div class="row">
    <div class="col-md-8">
        <div class="card">
            <div class="card-body">
                <form action="upload.php" method="post" enctype="multipart/form-data">
                    <div class="mb-3">
                        <label for="images" class="form-label">Select Images</label>
                        <input class="form-control" type="file" id="images" name="images[]" multiple accept="image/*" required>
                        <div class="form-text">You can select multiple images to upload at once.</div>
                    </div>
                    
                    <div class="mb-3">
                        <label for="title" class="form-label">Title</label>
                        <input type="text" class="form-control" id="title" name="title" placeholder="Image title">
                        <div class="form-text">If uploading multiple images, this will be used as a base title with numbers appended.</div>
                    </div>
                    
                    <div class="mb-3">
                        <label for="description" class="form-label">Description</label>
                        <textarea class="form-control" id="description" name="description" rows="3" placeholder="Image description"></textarea>
                    </div>
                    
                    <div class="mb-3">
                        <label for="album_id" class="form-label">Add to Album (Optional)</label>
                        <select class="form-select" id="album_id" name="album_id">
                            <option value="">-- Select Album --</option>
                            <?php foreach ($user_albums as $user_album): ?>
                            <option value="<?php echo $user_album['album_id']; ?>"><?php echo htmlspecialchars($user_album['album_name']); ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    
                    <div class="mb-3 form-check">
                        <input type="checkbox" class="form-check-input" id="is_public" name="is_public">
                        <label class="form-check-label" for="is_public">Make images public</label>
                        <div class="form-text">Public images will be visible to everyone.</div>
                    </div>
                    
                    <button type="submit" class="btn btn-primary">Upload</button>
                    <a href="my_images.php" class="btn btn-secondary">Cancel</a>
                </form>
            </div>
        </div>
    </div>
    
    <div class="col-md-4">
        <div class="card">
            <div class="card-header">
                Upload Tips
            </div>
            <div class="card-body">
                <ul>
                    <li>Supported formats: JPEG, PNG, GIF</li>
                    <li>Maximum file size: 5MB per image</li>
                    <li>For best quality, use high-resolution images</li>
                    <li>Add descriptive titles and descriptions for better organization</li>
                    <li>Use albums to organize related images</li>
                </ul>
            </div>
        </div>
    </div>
</div>

<?php
// Include footer
include 'includes/footer.php';
?>
