<?php
/**
 * View Album page for the photo gallery
 */
require_once 'config.php';
require_once 'includes/session.php';
require_once 'includes/album.php';

// Initialize session
$session = Session::getInstance();
$user = $session->getUser();

// Check if album ID is provided
if (!isset($_GET['id']) || empty($_GET['id'])) {
    $_SESSION['error'] = 'Album ID is required.';
    header('Location: index.php');
    exit;
}

$album_id = (int)$_GET['id'];

// Get album data
$album = new Album();
$album_data = $album->getAlbumById($album_id);

// Check if album exists
if (!$album_data) {
    $_SESSION['error'] = 'Album not found.';
    header('Location: index.php');
    exit;
}

// Check if user has permission to view this album
if (!$album_data['is_public'] && (!$user || $user->getUserId() != $album_data['user_id'])) {
    $_SESSION['error'] = 'You do not have permission to view this album.';
    header('Location: index.php');
    exit;
}

// Get album images
$album_images = $album->getAlbumImages($album_id);

// Set page title
$page_title = $album_data['album_name'];

// Include header
include 'includes/header.php';
?>

<div class="row">
    <div class="col-md-12">
        <nav aria-label="breadcrumb">
            <ol class="breadcrumb">
                <li class="breadcrumb-item"><a href="index.php">Home</a></li>
                <?php if ($user && $user->getUserId() == $album_data['user_id']): ?>
                <li class="breadcrumb-item"><a href="my_albums.php">My Albums</a></li>
                <?php else: ?>
                <li class="breadcrumb-item"><a href="explore.php">Explore</a></li>
                <?php endif; ?>
                <li class="breadcrumb-item active" aria-current="page"><?php echo htmlspecialchars($album_data['album_name']); ?></li>
            </ol>
        </nav>
    </div>
</div>

<div class="row">
    <div class="col-md-12">
        <div class="d-flex justify-content-between align-items-center mb-4">
            <h1><?php echo htmlspecialchars($album_data['album_name']); ?></h1>
            <?php if ($user && $user->getUserId() == $album_data['user_id']): ?>
            <div>
                <a href="edit_album.php?id=<?php echo $album_id; ?>" class="btn btn-primary">
                    <i class="fas fa-edit"></i> Edit Album
                </a>
                <button type="button" class="btn btn-danger" data-bs-toggle="modal" data-bs-target="#deleteAlbumModal">
                    <i class="fas fa-trash"></i> Delete Album
                </button>
            </div>
            <?php endif; ?>
        </div>
        
        <?php if (!empty($album_data['description'])): ?>
        <div class="mb-4">
            <p><?php echo nl2br(htmlspecialchars($album_data['description'])); ?></p>
        </div>
        <?php endif; ?>
        
        <div class="mb-4">
            <p class="text-muted">
                <i class="fas fa-user"></i> Created by: <?php echo htmlspecialchars($album_data['user_name']); ?> |
                <i class="fas fa-calendar"></i> Created: <?php echo date('F d, Y', strtotime($album_data['created_at'])); ?> |
                <i class="fas fa-image"></i> <?php echo count($album_images); ?> images |
                <i class="fas fa-<?php echo $album_data['is_public'] ? 'globe' : 'lock'; ?>"></i> <?php echo $album_data['is_public'] ? 'Public' : 'Private'; ?>
            </p>
        </div>
        
        <hr>
    </div>
</div>

<?php if (empty($album_images)): ?>
<div class="row">
    <div class="col-md-12">
        <div class="alert alert-info">
            <p>This album doesn't have any images yet.</p>
            <?php if ($user && $user->getUserId() == $album_data['user_id']): ?>
            <a href="upload.php" class="btn btn-primary">Upload Images</a>
            <?php endif; ?>
        </div>
    </div>
</div>
<?php else: ?>
<div class="row">
    <?php foreach ($album_images as $img): ?>
    <div class="col-md-3 mb-4">
        <div class="card h-100">
            <a href="view_image.php?id=<?php echo $img['image_id']; ?>">
                <img src="<?php echo htmlspecialchars($img['thumbnail_path']); ?>" class="card-img-top" alt="<?php echo htmlspecialchars($img['title'] ?: $img['file_name']); ?>">
            </a>
            <div class="card-body">
                <h5 class="card-title"><?php echo htmlspecialchars($img['title'] ?: 'Untitled'); ?></h5>
                <p class="card-text small text-muted"><?php echo date('M d, Y', strtotime($img['upload_date'])); ?></p>
                <a href="view_image.php?id=<?php echo $img['image_id']; ?>" class="btn btn-sm btn-primary">View</a>
                <?php if ($user && $user->getUserId() == $album_data['user_id']): ?>
                <form action="remove_from_album.php" method="post" class="d-inline">
                    <input type="hidden" name="album_id" value="<?php echo $album_id; ?>">
                    <input type="hidden" name="image_id" value="<?php echo $img['image_id']; ?>">
                    <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('Remove this image from the album?')">Remove</button>
                </form>
                <?php if (!$album_data['cover_image_id'] || $album_data['cover_image_id'] != $img['image_id']): ?>
                <form action="set_album_cover.php" method="post" class="d-inline">
                    <input type="hidden" name="album_id" value="<?php echo $album_id; ?>">
                    <input type="hidden" name="image_id" value="<?php echo $img['image_id']; ?>">
                    <button type="submit" class="btn btn-sm btn-secondary">Set as Cover</button>
                </form>
                <?php endif; ?>
                <?php endif; ?>
            </div>
        </div>
    </div>
    <?php endforeach; ?>
</div>
<?php endif; ?>

<?php if ($user && $user->getUserId() == $album_data['user_id']): ?>
<!-- Delete Album Modal -->
<div class="modal fade" id="deleteAlbumModal" tabindex="-1" aria-labelledby="deleteAlbumModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="deleteAlbumModalLabel">Confirm Delete</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <p>Are you sure you want to delete this album?</p>
                <p class="text-danger">This will only delete the album, not the images in it.</p>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                <form action="delete_album.php" method="post">
                    <input type="hidden" name="album_id" value="<?php echo $album_id; ?>">
                    <button type="submit" class="btn btn-danger">Delete Album</button>
                </form>
            </div>
        </div>
    </div>
</div>
<?php endif; ?>

<?php
// Include footer
include 'includes/footer.php';
?>
