<?php
/**
 * View Image page for the photo gallery
 */
require_once 'config.php';
require_once 'includes/session.php';
require_once 'includes/image.php';
require_once 'includes/album.php';

// Initialize session
$session = Session::getInstance();
$user = $session->getUser();

// Check if image ID is provided
if (!isset($_GET['id']) || empty($_GET['id'])) {
    $_SESSION['error'] = 'Image ID is required.';
    header('Location: index.php');
    exit;
}

$image_id = (int)$_GET['id'];

// Get image data
$image = new Image();
$img_data = $image->getImageById($image_id);

// Check if image exists
if (!$img_data) {
    $_SESSION['error'] = 'Image not found.';
    header('Location: index.php');
    exit;
}

// Check if user has permission to view this image
if (!$img_data['is_public'] && (!$user || $user->getUserId() != $img_data['user_id'])) {
    $_SESSION['error'] = 'You do not have permission to view this image.';
    header('Location: index.php');
    exit;
}

// Set page title
$page_title = $img_data['title'] ?: 'View Image';

// Include header
include 'includes/header.php';
?>

<div class="row">
    <div class="col-md-12">
        <nav aria-label="breadcrumb">
            <ol class="breadcrumb">
                <li class="breadcrumb-item"><a href="index.php">Home</a></li>
                <?php if ($user && $user->getUserId() == $img_data['user_id']): ?>
                <li class="breadcrumb-item"><a href="my_images.php">My Images</a></li>
                <?php else: ?>
                <li class="breadcrumb-item"><a href="explore.php">Explore</a></li>
                <?php endif; ?>
                <li class="breadcrumb-item active" aria-current="page"><?php echo htmlspecialchars($img_data['title'] ?: 'Untitled'); ?></li>
            </ol>
        </nav>
    </div>
</div>

<div class="row">
    <div class="col-md-8">
        <div class="card mb-4 image-detail">
            <div class="card-body text-center">
                <img src="<?php echo htmlspecialchars($img_data['file_path']); ?>" class="img-fluid" alt="<?php echo htmlspecialchars($img_data['title'] ?: $img_data['file_name']); ?>">
            </div>
        </div>
    </div>
    
    <div class="col-md-4">
        <div class="card mb-4">
            <div class="card-header">
                <h5 class="card-title mb-0"><?php echo htmlspecialchars($img_data['title'] ?: 'Untitled'); ?></h5>
            </div>
            <div class="card-body">
                <?php if (!empty($img_data['description'])): ?>
                <p class="card-text"><?php echo nl2br(htmlspecialchars($img_data['description'])); ?></p>
                <hr>
                <?php endif; ?>
                
                <div class="d-flex align-items-center mb-2">
                    <span class="me-2"><i class="fas fa-user"></i> Uploaded by:</span>
                    <span><?php echo htmlspecialchars($img_data['user_name']); ?></span>
                </div>
                
                <div class="d-flex align-items-center mb-2">
                    <span class="me-2"><i class="fas fa-calendar"></i> Upload date:</span>
                    <span><?php echo date('F d, Y', strtotime($img_data['upload_date'])); ?></span>
                </div>
                
                <div class="d-flex align-items-center mb-2">
                    <span class="me-2"><i class="fas fa-image"></i> Dimensions:</span>
                    <span><?php echo $img_data['width']; ?> x <?php echo $img_data['height']; ?> pixels</span>
                </div>
                
                <div class="d-flex align-items-center mb-2">
                    <span class="me-2"><i class="fas fa-file"></i> File size:</span>
                    <span><?php echo round($img_data['file_size'] / 1024, 2); ?> KB</span>
                </div>
                
                <div class="d-flex align-items-center mb-2">
                    <span class="me-2"><i class="fas fa-lock"></i> Visibility:</span>
                    <span><?php echo $img_data['is_public'] ? 'Public' : 'Private'; ?></span>
                </div>
                
                <?php if ($user && $user->getUserId() == $img_data['user_id']): ?>
                <hr>
                <div class="d-flex justify-content-between">
                    <a href="edit_image.php?id=<?php echo $img_data['image_id']; ?>" class="btn btn-primary">
                        <i class="fas fa-edit"></i> Edit
                    </a>
                    <button type="button" class="btn btn-danger" data-bs-toggle="modal" data-bs-target="#deleteModal">
                        <i class="fas fa-trash"></i> Delete
                    </button>
                </div>
                <?php endif; ?>
            </div>
        </div>
    </div>
</div>

<?php if ($user && $user->getUserId() == $img_data['user_id']): ?>
<!-- Delete Confirmation Modal -->
<div class="modal fade" id="deleteModal" tabindex="-1" aria-labelledby="deleteModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="deleteModalLabel">Confirm Delete</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                Are you sure you want to delete this image? This action cannot be undone.
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                <form action="delete_image.php" method="post">
                    <input type="hidden" name="image_id" value="<?php echo $img_data['image_id']; ?>">
                    <button type="submit" class="btn btn-danger">Delete</button>
                </form>
            </div>
        </div>
    </div>
</div>
<?php endif; ?>

<?php
// Include footer
include 'includes/footer.php';
?>
